#
# Copyright (c) 2008-2017 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces

# import packages
from zope.interface import Interface
from zope.schema import Bool, Choice
from zope.schema.vocabulary import SimpleVocabulary, SimpleTerm

from pyams_default_theme import _


CONTENT_POSITIONS = (
    {'id': 'left', 'title': _("Left")},
    {'id': 'right', 'title': _("Right")}
)

CONTENT_POSITIONS_VOCABULARY = SimpleVocabulary([SimpleTerm(item['id'], title=item['title'])
                                                for item in CONTENT_POSITIONS])


class IContactParagraphDefaultRendererSettings(Interface):
    """Contact paragraph default renderer settings interface"""

    display_photo = Bool(title=_("Show photo?"),
                         description=_("Display contact photo"),
                         required=True,
                         default=True)

    photo_position = Choice(title=_("Photo position"),
                            required=False,
                            vocabulary=CONTENT_POSITIONS_VOCABULARY,
                            default='left')

    def can_display_photo(self):
        """Check if photo can be displayed"""

    display_map = Bool(title=_("Show location map?"),
                       description=_("If 'no', location map will not be displayed"),
                       required=True,
                       default=True)

    map_position = Choice(title=_("Map position"),
                          required=False,
                          vocabulary=CONTENT_POSITIONS_VOCABULARY,
                          default='right')

    def can_display_map(self):
        """Check if location map can be displayed"""
